@@ -561,8 +561,12 @@ class ShellCommand(Command):
 
             # try to use IPython if possible
             try:
-                # ipython >= 0.11
-                from IPython.frontend.terminal.embed import InteractiveShellEmbed
+                try:
+                    # 1.0 <= ipython
+                    from IPython.terminal.embed import InteractiveShellEmbed
+                except ImportError:
+                    # 0.11 <= ipython < 1.0
+                    from IPython.frontend.terminal.embed import InteractiveShellEmbed
                 shell = InteractiveShellEmbed(banner2=banner)
             except ImportError:
                 # ipython < 0.11
