@@ -1,26 +1,26 @@
 """The base WSGI XMLRPCController"""
 import inspect
 import logging
-import sys
+import types
 import xmlrpclib
 
 from paste.response import replace_header
-from paste.wsgiwrappers import WSGIResponse
 
 from pylons.controllers import WSGIController
-from pylons.controllers.util import abort
+from pylons.controllers.util import abort, Response
 
 __all__ = ['XMLRPCController']
 
 log = logging.getLogger(__name__)
 
 XMLRPC_MAPPING = ((basestring, 'string'), (list, 'array'), (bool, 'boolean'),
-                  (int, 'int'), (float, 'double'), (dict, 'struct'), 
+                  (int, 'int'), (float, 'double'), (dict, 'struct'),
                   (xmlrpclib.DateTime, 'dateTime.iso8601'),
                   (xmlrpclib.Binary, 'base64'))
 
+
 def xmlrpc_sig(args):
-    """Returns a list of the function signature in string format based on a 
+    """Returns a list of the function signature in string format based on a
     tuple provided by xmlrpclib."""
     signature = []
     for param in args:
@@ -34,32 +34,33 @@ def xmlrpc_sig(args):
 def xmlrpc_fault(code, message):
     """Convienence method to return a Pylons response XMLRPC Fault"""
     fault = xmlrpclib.Fault(code, message)
-    return WSGIResponse(xmlrpclib.dumps(fault, methodresponse=True))
+    return Response(body=xmlrpclib.dumps(fault, methodresponse=True))
 
 
 class XMLRPCController(WSGIController):
     """XML-RPC Controller that speaks WSGI
-    
-    This controller handles XML-RPC responses and complies with the 
-    `XML-RPC Specification <http://www.xmlrpc.com/spec>`_ as well as the
-    `XML-RPC Introspection
-    <http://scripts.incutio.com/xmlrpc/introspection.html>`_ specification.
-    
-    By default, methods with names containing a dot are translated to use an
-    underscore. For example, the `system.methodHelp` is handled by the method 
-    `system_methodHelp`.
-    
-    Methods in the XML-RPC controller will be called with the method given in 
-    the XMLRPC body. Methods may be annotated with a signature attribute to 
-    declare the valid arguments and return types.
-    
+
+    This controller handles XML-RPC responses and complies with the
+    `XML-RPC Specification <http://www.xmlrpc.com/spec>`_ as well as
+    the `XML-RPC Introspection
+    <http://scripts.incutio.com/xmlrpc/introspection.html>`_
+    specification.
+
+    By default, methods with names containing a dot are translated to
+    use an underscore. For example, the `system.methodHelp` is handled
+    by the method :meth:`system_methodHelp`.
+
+    Methods in the XML-RPC controller will be called with the method
+    given in the XMLRPC body. Methods may be annotated with a signature
+    attribute to declare the valid arguments and return types.
+
     For example::
-        
+
         class MyXML(XMLRPCController):
             def userstatus(self):
                 return 'basic string'
             userstatus.signature = [ ['string'] ]
-            
+
             def userinfo(self, username, age=None):
                 user = LookUpUser(username)
                 response = {'username':user.name}
@@ -68,18 +69,18 @@ class XMLRPCController(WSGIController):
                 return response
             userinfo.signature = [['struct', 'string'],
                                   ['struct', 'string', 'int']]
-    
-    Since XML-RPC methods can take different sets of data, each set of valid
-    arguments is its own list. The first value in the list is the type of the
-    return argument. The rest of the arguments are the types of the data that
-    must be passed in.
-    
-    In the last method in the example above, since the method can optionally 
-    take an integer value both sets of valid parameter lists should be
-    provided.
-    
-    Valid types that can be checked in the signature and their corresponding
-    Python types::
+
+    Since XML-RPC methods can take different sets of data, each set of
+    valid arguments is its own list. The first value in the list is the
+    type of the return argument. The rest of the arguments are the
+    types of the data that must be passed in.
+
+    In the last method in the example above, since the method can
+    optionally take an integer value both sets of valid parameter lists
+    should be provided.
+
+    Valid types that can be checked in the signature and their
+    corresponding Python types::
 
         'string' - str
         'array' - list
@@ -89,14 +90,15 @@ class XMLRPCController(WSGIController):
         'struct' - dict
         'dateTime.iso8601' - xmlrpclib.DateTime
         'base64' - xmlrpclib.Binary
-    
-    The class variable ``allow_none`` is passed to xmlrpclib.dumps; enabling it
-    allows translating ``None`` to XML (an extension to the XML-RPC
-    specification)
 
-    Note::
+    The class variable ``allow_none`` is passed to xmlrpclib.dumps;
+    enabling it allows translating ``None`` to XML (an extension to the
+    XML-RPC specification)
+
+    .. note::
 
         Requiring a signature is optional.
+
     """
     allow_none = False
     max_body_length = 4194304
@@ -105,7 +107,7 @@ class XMLRPCController(WSGIController):
         return self.rpc_kargs
 
     def __call__(self, environ, start_response):
-        """Parse an XMLRPC body for the method, and call it with the 
+        """Parse an XMLRPC body for the method, and call it with the
         appropriate arguments"""
         # Pull out the length, return an error if there is no valid
         # length or if the length is larger than the max_body_length.
@@ -134,8 +136,8 @@ class XMLRPCController(WSGIController):
             if log_debug:
                 log.debug("Method: %r not found, returning xmlrpc fault",
                           method)
-            return xmlrpc_fault(0, "No such method name")(environ,
-                                                          start_response)
+            return xmlrpc_fault(0, "No such method name %r" %
+                                method)(environ, start_response)
 
         # Signature checking for params
         if hasattr(func, 'signature'):
@@ -145,7 +147,7 @@ class XMLRPCController(WSGIController):
             params = xmlrpc_sig(rpc_args)
             for sig in func.signature:
                 # Next sig if we don't have the same amount of args
-                if len(sig)-1 != len(rpc_args):
+                if len(sig) - 1 != len(rpc_args):
                     continue
 
                 # If the params match, we're valid
@@ -170,17 +172,20 @@ class XMLRPCController(WSGIController):
         kargs['start_response'] = start_response
         self.rpc_kargs = kargs
         self._func = func
-        
+
         # Now that we know the method is valid, and the args are valid,
         # we can dispatch control to the default WSGIController
         status = []
         headers = []
         exc_info = []
+
         def change_content(new_status, new_headers, new_exc_info=None):
             status.append(new_status)
             headers.extend(new_headers)
             exc_info.append(new_exc_info)
         output = WSGIController.__call__(self, environ, change_content)
+        output = list(output)
+        headers.append(('Content-Length', str(len(output[0]))))
         replace_header(headers, 'Content-Type', 'text/xml')
         start_response(status[0], headers, exc_info[0])
         return output
@@ -193,32 +198,41 @@ class XMLRPCController(WSGIController):
 
         response = xmlrpclib.dumps(raw_response, methodresponse=True,
                                    allow_none=self.allow_none)
-        return WSGIResponse(response)
+        return response
 
     def _find_method(self, name):
-        """Locate a method in the controller by the specified name and return
-        it
-        """
+        """Locate a method in the controller by the specified name and
+        return it"""
+        # Keep private methods private
+        if name.startswith('_'):
+            if self._pylons_log_debug:
+                log.debug("Action starts with _, private action not allowed")
+            return
+
         if self._pylons_log_debug:
             log.debug("Looking for XMLRPC method: %r", name)
         try:
-            return getattr(self, name, None)
+            func = getattr(self, name, None)
         except UnicodeEncodeError:
             return
+        if isinstance(func, types.MethodType):
+            return func
 
     def _find_method_name(self, name):
         """Locate a method in the controller by the appropriate name
-        
-        By default, this translates method names like 'system.methodHelp' into
-        'system_methodHelp'.
+
+        By default, this translates method names like
+        'system.methodHelp' into 'system_methodHelp'.
+
         """
         return name.replace('.', '_')
 
     def _publish_method_name(self, name):
         """Translate an internal method name to a publicly viewable one
-        
-        By default, this translates internal method names like 'blog_view' into
-        'blog.view'.
+
+        By default, this translates internal method names like
+        'blog_view' into 'blog.view'.
+
         """
         return name.replace('_', '.')
 
@@ -228,18 +242,20 @@ class XMLRPCController(WSGIController):
         for method in dir(self):
             meth = getattr(self, method)
 
-            # Only methods have this attribute
-            if not method.startswith('_') and hasattr(meth, 'im_self'):
+            if not method.startswith('_') and isinstance(meth,
+                                                         types.MethodType):
                 methods.append(self._publish_method_name(method))
         return methods
     system_listMethods.signature = [['array']]
 
     def system_methodSignature(self, name):
-        """Returns an array of array's for the valid signatures for a method.
+        """Returns an array of array's for the valid signatures for a
+        method.
+
+        The first value of each array is the return value of the
+        method. The result is an array to indicate multiple signatures
+        a method may be capable of.
 
-        The first value of each array is the return value of the method. The
-        result is an array to indicate multiple signatures a method may be
-        capable of.
         """
         method = self._find_method(self._find_method_name(name))
         if method:
@@ -263,7 +279,8 @@ class XMLRPCController(WSGIController):
 
 
 class MethodHelp(object):
-    """Wrapper for formatting doc strings from XMLRPCController methods"""
+    """Wrapper for formatting doc strings from XMLRPCController
+    methods"""
     def __init__(self, doc):
         self.__doc__ = doc
 
