@@ -15,17 +15,18 @@ __all__ = ['_', 'add_fallback', 'get_lang', 'gettext', 'gettext_noop',
            'ngettext', 'set_lang', 'ugettext', 'ungettext', 'LanguageError',
            'N_']
 
+
 class LanguageError(Exception):
     """Exception raised when a problem occurs with changing languages"""
     pass
 
 
 class LazyString(object):
-    """Has a number of lazily evaluated functions replicating a 
+    """Has a number of lazily evaluated functions replicating a
     string. Just override the eval() method to produce the actual value.
 
     This method copied from TurboGears.
-    
+
     """
     def __init__(self, func, *args, **kwargs):
         self.func = func
@@ -44,8 +45,8 @@ class LazyString(object):
     def __mod__(self, other):
         return self.eval() % other
 
-    def format(self, other):
-        return self.eval().format(other)
+    def format(self, *args):
+        return self.eval().format(*args)
 
 
 def lazify(func):
@@ -101,7 +102,7 @@ def ugettext(value):
     Mark a string to be localized as follows::
 
         _('This should be in lots of languages')
-    
+
     """
     return pylons.translator.ugettext(value)
 _ = ugettext
@@ -167,7 +168,7 @@ def _get_translator(lang, **kwargs):
     return translator
 
 
-def set_lang(lang, **kwargs):
+def set_lang(lang, set_environ=True, **kwargs):
     """Set the current language used for translations.
 
     ``lang`` should be a string or a list of strings. If a list of
@@ -175,6 +176,8 @@ def set_lang(lang, **kwargs):
     languages are added as fallbacks.
     """
     translator = _get_translator(lang, **kwargs)
+    if not set_environ:
+        return translator
     environ = pylons.request.environ
     environ['pylons.pylons'].translator = translator
     if 'paste.registry' in environ:
