@@ -1,7 +1,5 @@
 from pylons import app_globals
 from pylons.decorators.cache import beaker_cache
-# from pylons.templating import render_response
-from pylons.templating import render_mako
 from projectname.lib.base import BaseController
 
 class CacheController(BaseController):
@@ -30,4 +28,3 @@ class CacheController(BaseController):
     def test_keyslist_cache_decorator(self, id, id2="123"):
         app_globals.counter += 1
         return 'Counter=%s, id=%s' % (app_globals.counter, id)
-
