@@ -2,14 +2,13 @@ import datetime
 
 from projectname.lib.base import *
 import projectname.lib.helpers as h
-# from pylons import h as deprecated_h
-from pylons import request, response, session
+from pylons import request, response, session, url
 from pylons import tmpl_context as c
 from pylons import app_globals
 from pylons.decorators import rest
 from pylons.i18n import _, get_lang, set_lang, LanguageError
 from pylons.templating import render_mako, render_genshi, render_jinja2
-from pylons.controllers.util import abort, redirect_to, url_for
+from pylons.controllers.util import abort, redirect
 
 class SampleController(BaseController):
     def index(self):
@@ -30,7 +29,7 @@ class SampleController(BaseController):
         return str(app_globals.counter)
     
     def myself(self):
-        return h.url_for()
+        return request.url
     
     def myparams(self):
         return str(request.params)
@@ -38,10 +37,6 @@ class SampleController(BaseController):
     def testdefault(self):
         c.test = "This is in c var"
         return render_genshi('testgenshi.html')
-
-    # def testdefault_legacy(self):
-    #     c.test = "This is in c var"
-    #     return old_render('testgenshi')
         
     def test_template_caching(self):
         return render_mako('/test_mako.html', cache_expire='never')
@@ -94,6 +89,3 @@ class SampleController(BaseController):
         set_lang([])
         response.write(_('No languages'))
         return ''
-        
-    # def deprecated_h(self):
-    #     return '%s is %s' % (h.url_for(), deprecated_h.url_for())
